@@ -12,7 +12,7 @@ import click
 from ..db import init_db_pool
 from .alarms import AlarmsView, AlarmView
 from .listeners import ListenersView, ListenerView
-from .proximity import ProximityView, proximity_task
+from .proximity import ProximityView, proximity_task, ProximityXMLView
 from .tags import TagsView, TagView, TagHistoryView, TagContactView
 from .zones import ZonesView, ZoneView
 from .groups import GroupsView, GroupView
@@ -35,7 +35,7 @@ def main(port, demo_fe) -> None:
         loop.add_signal_handler(signal.SIGINT, loop.stop)
 
     async def init_db_app(app):
-        app['db_pool'] = await init_db_pool()
+        app['db_pool'] = await init_db_pool('api')
         asyncio.ensure_future(proximity_task(app['db_pool']))
 
     app = web.Application()
@@ -50,6 +50,7 @@ def main(port, demo_fe) -> None:
     app.router.add_view('/api/tags/{id:\d+}/history', TagHistoryView, name='history')
     app.router.add_view('/api/tags/{id:\d+}/contacts', TagContactView, name='contacts')
     app.router.add_view('/api/proximity', ProximityView)
+    app.router.add_view('/api/proximity.xml', ProximityXMLView)
     app.router.add_view('/api/groups', GroupsView)
     app.router.add_view('/api/groups/{id:\d+}', GroupView, name='group')
     app.router.add_view('/api/alarms', AlarmsView)
