@@ -16,4 +16,12 @@ CONFIG = {
     'MAX_DB_CONNECTIONS': int(os.getenv('MAX_DB_CONNECTIONS', 4)),
     'MAX_QUEUED_PACKETS': int(os.getenv('MAX_QUEUED_PACKETS', 100)),
     'LAST_SEEN_RESOLUTION_SECS': int(os.getenv('LAST_SEEN_RESOLUTION_SECS', 5)),
+    'MIN_SEC_IN_LOCATION': int(os.getenv('MIN_SEC_IN_LOCATION', 10)),
+    'MIN_SEC_IN_LOCATION_IF_RETURNING': int(os.getenv('MIN_SEC_IN_LOCATION_IF_RETURNING', 30)),
+}
+
+DB_RELEVANT = {
+    'ingest': {'MIN_SEC_IN_LOCATION': CONFIG['MIN_SEC_IN_LOCATION'],
+               'MIN_SEC_IN_LOCATION_IF_RETURNING': CONFIG['MIN_SEC_IN_LOCATION_IF_RETURNING']},
+    'api': {}
 }
