@@ -26,7 +26,7 @@ def main(port) -> None:
     if signal is not None and os.name != 'nt':
         loop.add_signal_handler(signal.SIGINT, loop.stop)
 
-    db_pool = loop.run_until_complete(init_db_pool())
+    db_pool = loop.run_until_complete(init_db_pool('ingest'))
     ListenerProtocol.db_pool = db_pool
 
     stats.run(CONFIG['STATS_INTERVAL'])
